# libkizano.py
Kizano Library for the things I found very valuable in Python I can open-source.

Contains generic functions that pertain to no IP nor belong to any one organization or entity.

All code within this project is contained as-is without warranty or liability.
All code under this repository is relased to the public under the GNU License (GNU-GPLv3).
